var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug = require("debug");
const path = require("path");
const spawn_1 = require("./spawn");
const helpers_1 = require("./helpers");
const d = debug('electron-notarize');
function startNotarize(opts) {
    return __awaiter(this, void 0, void 0, function* () {
        d('starting notarize process for app:', opts.appPath);
        return yield helpers_1.withTempDir((dir) => __awaiter(this, void 0, void 0, function* () {
            const zipPath = path.resolve(dir, `${path.basename(opts.appPath, '.app')}.zip`);
            d('zipping application to:', zipPath);
            const zipResult = yield spawn_1.spawn('zip', [
                '-r',
                '-y',
                zipPath,
                path.basename(opts.appPath),
            ], {
                cwd: path.dirname(opts.appPath),
            });
            if (zipResult.code !== 0) {
                throw new Error(`Failed to zip application, exited with code: ${zipResult.code}\n\n${zipResult.output}`);
            }
            d('zip succeeded, attempting to upload to apple');
            const result = yield spawn_1.spawn('xcrun', [
                'altool',
                '--notarize-app',
                '-f',
                zipPath,
                '--primary-bundle-id',
                opts.appBundleId,
                '-u',
                helpers_1.makeSecret(opts.appleId),
                '-p',
                helpers_1.makeSecret(opts.appleIdPassword),
            ]);
            if (result.code !== 0) {
                throw new Error(`Failed to upload app to Apples notarization servers\n\n${result.output}`);
            }
            d('upload success');
            const uuidMatch = /\nRequestUUID = (.+?)\n/g.exec(result.output);
            if (!uuidMatch) {
                throw new Error(`Failed to find request UUID in output:\n\n${result.output}`);
            }
            d('found UUID:', uuidMatch[1]);
            return {
                uuid: uuidMatch[1],
            };
        }));
    });
}
exports.startNotarize = startNotarize;
function waitForNotarize(opts) {
    return __awaiter(this, void 0, void 0, function* () {
        d('checking notarization status:', opts.uuid);
        const result = yield spawn_1.spawn('xcrun', [
            'altool',
            '--notarization-info',
            opts.uuid,
            '-u',
            helpers_1.makeSecret(opts.appleId),
            '-p',
            helpers_1.makeSecret(opts.appleIdPassword),
        ]);
        if (result.code !== 0) {
            throw new Error(`Failed to check status of notarization request: ${opts.uuid}\n\n${result.output}`);
        }
        const notarizationInfo = helpers_1.parseNotarizationInfo(result.output);
        if (notarizationInfo.status === 'in progress') {
            d('still in progress, waiting 30 seconds');
            yield new Promise(r => setTimeout(r, 30000));
            return waitForNotarize(opts);
        }
        d('notarzation done with info:', notarizationInfo);
        if (notarizationInfo.status === 'invalid') {
            d('notarization failed');
            throw new Error(`Apple failed to notarize your application, check the logs for more info

Status Code: ${notarizationInfo.statusCode || 'No Code'}
Message: ${notarizationInfo.statusMessage || 'No Message'}
Logs: ${notarizationInfo.logFileUrl}`);
        }
        if (notarizationInfo.status !== 'success') {
            throw new Error(`Unrecognized notarization status: "${notarizationInfo.status}"`);
        }
        d('notarization was successful');
        return;
    });
}
exports.waitForNotarize = waitForNotarize;
function stapleApp(opts) {
    return __awaiter(this, void 0, void 0, function* () {
        d('attempting to staple app:', opts.appPath);
        const result = yield spawn_1.spawn('xcrun', [
            'stapler',
            'staple',
            '-v',
            path.basename(opts.appPath),
        ], {
            cwd: path.dirname(opts.appPath),
        });
        if (result.code !== 0) {
            throw new Error(`Failed to staple your application with code: ${result.code}\n\n${result.output}`);
        }
        d('staple succeeded');
        return;
    });
}
exports.stapleApp = stapleApp;
function notarize({ appBundleId, appPath, appleId, appleIdPassword, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const { uuid } = yield startNotarize({
            appBundleId,
            appPath,
            appleId,
            appleIdPassword,
        });
        yield waitForNotarize({ uuid, appleId, appleIdPassword });
        yield stapleApp({ appPath });
    });
}
exports.notarize = notarize;
//# sourceMappingURL=index.js.map